@@ -391,10 +391,11 @@ setMethod("show", "H2OBinomialMetrics", function(object) {
     cat("AUC:  ", object@metrics$AUC, "\n", sep="")
     cat("Gini:  ", object@metrics$Gini, "\n", sep="")
     if(exists(object@algorithm) && object@algorithm == "glm") {
-      if (!is.na(object@metrics$r2)) cat("R^2:  ", object@metrics$r2, "\n", sep="")
-      cat("Null Deviance:  ", object@metrics$null_deviance,"\n", sep="")
-      cat("Residual Deviance:  ", object@metrics$residual_deviance,"\n", sep="")
-      cat("AIC:  ", object@metrics$AIC,"\n", sep="")
+
+      if (!is.null(object@metrics$r2) && !is.na(object@metrics$r2)) cat("R^2:  ", object@metrics$r2, "\n", sep="")
+      if (!is.null(object@metrics$null_deviance0)) cat("Null Deviance:  ", object@metrics$null_deviance,"\n", sep="")
+      if (!is.null(object@metrics$residual_deviance)) cat("Residual Deviance:  ", object@metrics$residual_deviance,"\n", sep="")
+      if (!is.null(object@metrics$AIC)) cat("AIC:  ", object@metrics$AIC,"\n", sep="")
     }
     cat("\n")
     cm <- h2o.confusionMatrix(object)
@@ -612,3 +613,12 @@ setMethod("summary", "H2OGrid",
               cat("\nNote: To see exception stack traces please pass parameter `show_stack_traces = T` to this function.\n")
             }
 })
+
+#'
+#' The H2OFrame class
+#'
+#' This class represents an H2OFrame object
+#'
+#' @export
+setClass("H2OFrame")
+
