@@ -30,8 +30,16 @@
 #' @export
 h2o.parseRaw <- function(data, pattern="", destination_frame = "", header=NA, sep = "", col.names=NULL,
                          col.types=NULL, na.strings=NULL, blocking=FALSE, parse_type = NULL, chunk_size = NULL) {
-  parse.params <- h2o.parseSetup(data, pattern="", destination_frame, header, sep, col.names, col.types,
-                                 na.strings = na.strings, parse_type = parse_type, chunk_size = chunk_size)
+  # Check and parse col.types in case col.types is supplied col.name = col.type vec
+  if( length(names(col.types)) > 0 & typeof(col.types) != "list" ) {
+    parse.params <- h2o.parseSetup(data, pattern="", destination_frame, header, sep, col.names, col.types = NULL,
+                                   na.strings = na.strings, parse_type = parse_type, chunk_size = chunk_size)
+    idx = match(names(col.types), parse.params$column_names)
+    parse.params$column_types[idx] = as.character(col.types)
+  } else {
+    parse.params <- h2o.parseSetup(data, pattern="", destination_frame, header, sep, col.names, col.types,
+                                   na.strings = na.strings, parse_type = parse_type, chunk_size = chunk_size)
+  }
   for(w in parse.params$warnings){
     cat('WARNING:',w,'\n')
   }
